
Activation functions
------------------------

.. automodule:: flax.linen.activation
.. currentmodule:: flax.linen.activation

.. autoclass:: PReLU
  :members:
  :special-members: __call__

.. autofunction:: celu
.. autofunction:: elu
.. autofunction:: gelu
.. autofunction:: glu
.. autofunction:: hard_sigmoid
.. autofunction:: hard_silu
.. autofunction:: hard_swish
.. autofunction:: hard_tanh
.. autofunction:: leaky_relu
.. autofunction:: log_sigmoid
.. autofunction:: log_softmax
.. autofunction:: logsumexp
.. autofunction:: one_hot
.. autofunction:: relu
.. autofunction:: relu6 as relu6,
.. autofunction:: selu
.. autofunction:: sigmoid
.. autofunction:: silu
.. autofunction:: soft_sign
.. autofunction:: softmax
.. autofunction:: softplus
.. autofunction:: standardize
.. autofunction:: swish
.. autofunction:: tanh

**Summary**

.. autosummary::
  :toctree: _autosummary

  PReLU
  celu
  elu
  gelu
  glu
  hard_sigmoid
  hard_silu
  hard_swish
  hard_tanh
  leaky_relu
  log_sigmoid
  log_softmax
  logsumexp
  one_hot
  relu
  relu6 as relu6,
  selu
  sigmoid
  silu
  soft_sign
  softmax
  softplus
  standardize
  swish
  tanh